@@ -35,6 +35,7 @@
 #include "incidence.h"
 #include "calformat.h"
 
+
 #include <QTemporaryFile>
 #include <QMimeDatabase>
 #include <QTextDocument> // for .toHtmlEscaped() and Qt::mightBeRichText()
@@ -54,7 +55,7 @@ public:
     Private()
         : mGeoLatitude(INVALID_LATLON),
           mGeoLongitude(INVALID_LATLON),
-          mRecurrence(0),
+          mRecurrence(nullptr),
           mRevision(0),
           mPriority(0),
           mStatus(StatusNone),
@@ -81,7 +82,7 @@ public:
           mRecurrenceId(p.mRecurrenceId),
           mGeoLatitude(p.mGeoLatitude),
           mGeoLongitude(p.mGeoLongitude),
-          mRecurrence(0),
+          mRecurrence(nullptr),
           mRevision(p.mRevision),
           mPriority(p.mPriority),
           mStatus(p.mStatus),
@@ -100,7 +101,7 @@ public:
         mAlarms.clear();
         mAttachments.clear();
         delete mRecurrence;
-        mRecurrence = 0;
+        mRecurrence = nullptr;
     }
 
     void init(Incidence *dest, const Incidence &src)
@@ -128,14 +129,14 @@ public:
         // We need to really duplicate the objects stored therein, otherwise deleting
         // i will also delete all attachments from this object (setAutoDelete...)
         mAlarms.reserve(src.d->mAlarms.count());
-        foreach (const Alarm::Ptr &alarm, src.d->mAlarms) {
+       for (const Alarm::Ptr &alarm : qAsConst(src.d->mAlarms)) {
             Alarm::Ptr b(new Alarm(*alarm.data()));
             b->setParent(dest);
             mAlarms.append(b);
         }
 
         mAttachments.reserve(src.d->mAttachments.count());
-        foreach (const Attachment::Ptr &attachment, src.d->mAttachments) {
+        for (const Attachment::Ptr &attachment : qAsConst(src.d->mAttachments)) {
             Attachment::Ptr a(new Attachment(*attachment));
             mAttachments.append(a);
         }
@@ -144,7 +145,7 @@ public:
             mRecurrence = new Recurrence(*(src.d->mRecurrence));
             mRecurrence->addObserver(dest);
         } else {
-            mRecurrence = 0;
+            mRecurrence = nullptr;
         }
     }
 
@@ -198,8 +199,8 @@ Incidence::~Incidence()
 {
     // Alarm has a raw incidence pointer, so we must set it to 0
     // so Alarm doesn't use it after Incidence is destroyed
-    foreach (const Alarm::Ptr &alarm, d->mAlarms) {
-        alarm->setParent(0);
+    for (const Alarm::Ptr &alarm : qAsConst(d->mAlarms)) {
+        alarm->setParent(nullptr);
     }
     clearTempFiles();
     delete d->mRecurrence;
@@ -272,12 +273,12 @@ bool Incidence::equals(const IncidenceBase &incidence) const
         }
     }
 
-    bool recurrenceEqual = (d->mRecurrence == 0 && i2->d->mRecurrence == 0);
+    bool recurrenceEqual = (d->mRecurrence == nullptr && i2->d->mRecurrence == nullptr);
     if (!recurrenceEqual) {
         recurrence(); // create if doesn't exist
         i2->recurrence(); // create if doesn't exist
-        recurrenceEqual = d->mRecurrence != 0 &&
-                          i2->d->mRecurrence != 0 &&
+        recurrenceEqual = d->mRecurrence != nullptr &&
+                          i2->d->mRecurrence != nullptr &&
                           *d->mRecurrence == *i2->d->mRecurrence;
     }
 
@@ -530,7 +531,7 @@ QStringList Incidence::categories() const
 
 QString Incidence::categoriesStr() const
 {
-    return d->mCategories.join(QStringLiteral(","));
+    return d->mCategories.join(QLatin1Char(','));
 }
 
 void Incidence::setRelatedTo(const QString &relatedToUid, RelType relType)
@@ -569,7 +570,7 @@ Recurrence *Incidence::recurrence() const
 void Incidence::clearRecurrence()
 {
     delete d->mRecurrence;
-    d->mRecurrence = 0;
+    d->mRecurrence = nullptr;
 }
 
 ushort Incidence::recurrenceType() const
@@ -629,8 +630,8 @@ QList<KDateTime> Incidence::startDateTimesForDate(const QDate &date,
     KDateTime tmp;
     while (tmpday <= date) {
         if (recurrence()->recursOn(tmpday, timeSpec)) {
-            QList<QTime> times = recurrence()->recurTimesOn(tmpday, timeSpec);
-            foreach (const QTime &time, times) {
+            const QList<QTime> times = recurrence()->recurTimesOn(tmpday, timeSpec);
+            for (const QTime &time : times) {
                 tmp = KDateTime(tmpday, time, start.timeSpec());
                 if (endDateForStart(tmp) >= kdate) {
                     result << tmp;
@@ -669,8 +670,8 @@ QList<KDateTime> Incidence::startDateTimesForDateTime(const KDateTime &datetime)
     while (tmpday <= datetime.date()) {
         if (recurrence()->recursOn(tmpday, datetime.timeSpec())) {
             // Get the times during the day (in start date's time zone) when recurrences happen
-            QList<QTime> times = recurrence()->recurTimesOn(tmpday, start.timeSpec());
-            foreach (const QTime &time, times) {
+            const QList<QTime> times = recurrence()->recurTimesOn(tmpday, start.timeSpec());
+            for (const QTime &time : times) {
                 tmp = KDateTime(tmpday, time, start.timeSpec());
                 if (!(tmp > datetime || endDateForStart(tmp) < datetime)) {
                     result << tmp;
@@ -741,7 +742,7 @@ Attachment::List Incidence::attachments() const
 Attachment::List Incidence::attachments(const QString &mime) const
 {
     Attachment::List attachments;
-    foreach (const Attachment::Ptr &attachment, d->mAttachments) {
+    for (const Attachment::Ptr &attachment : qAsConst(d->mAttachments)) {
         if (attachment->mimeType() == mime) {
             attachments.append(attachment);
         }
@@ -757,8 +758,9 @@ void Incidence::clearAttachments()
 
 QString Incidence::writeAttachmentToTempFile(const Attachment::Ptr &attachment) const
 {
-    if (d->mTempFiles.contains(attachment)) {
-        return d->mTempFiles.value(attachment);
+    const QString attachementPath = d->mTempFiles.value(attachment);
+    if (!attachementPath.isEmpty()) {
+        return attachementPath;
     }
     QTemporaryFile file;
 
@@ -920,7 +922,7 @@ void Incidence::clearAlarms()
 
 bool Incidence::hasEnabledAlarms() const
 {
-    foreach (const Alarm::Ptr &alarm, d->mAlarms) {
+    for (const Alarm::Ptr &alarm : qAsConst(d->mAlarms)) {
         if (alarm->enabled()) {
             return true;
         }
@@ -1138,11 +1140,11 @@ void Incidence::serialize(QDataStream &out)
         out << d->mRecurrence;
     }
 
-    foreach (const Attachment::Ptr &attachment, d->mAttachments) {
+    for (const Attachment::Ptr &attachment : qAsConst(d->mAttachments)) {
         out << attachment;
     }
 
-    foreach (const Alarm::Ptr &alarm, d->mAlarms) {
+    for (const Alarm::Ptr &alarm : qAsConst(d->mAlarms)) {
         out << alarm;
     }
 }
